# Copyright 2025 The Pigweed Authors
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.
"""Adapters and helpers for Bazel runfiles handling."""

from dataclasses import dataclass
from pathlib import Path


@dataclass
class PythonRunfilesLabelAdapter:
    """A object that represents Bazel-provided runtime file resource.

    This isn't intended for direct instantiation in a codebase. Bazel will
    use this as the generated type for pw_py_importable_runfile libraries.
    """

    runfiles_path: Path
    source_repo: str

    def __iter__(self):
        """Custom iterator to support passing an adapter to Rlocation()."""
        yield self.runfiles_path
        yield self.source_repo
